==> jc-1.4.0.tar.gz: javax/net/ssl/SSLSessionBindingEvent.h <==
// public class javax.net.ssl.SSLSessionBindingEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 8266a1b5be5d34a2 javax_net_ssl_SSLSessionBindingEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_net_ssl_SSLSessionBindingEvent_H_
#define _JC_javax_net_ssl_SSLSessionBindingEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_net_ssl_SSLSession$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs	_jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs	_jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$refs	_jc_javax_net_ssl_SSLSessionBindingEvent$refs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs	_jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$object	_jc_javax_net_ssl_SSLSessionBindingEvent$object;

typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct	_jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLSessionBindingEvent$vmethods	_jc_javax_net_ssl_SSLSessionBindingEvent$vmethods;
typedef const struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtable	_jc_javax_net_ssl_SSLSessionBindingEvent$vtable;
typedef const struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtype	_jc_javax_net_ssl_SSLSessionBindingEvent$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct _jc_javax_net_ssl_SSLSessionBindingEvent$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLSessionBindingEvent$method$_init$0e0aa0347f23a9f5(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_SSLSessionBindingEvent$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *);
extern struct _jc_object *_jc_javax_net_ssl_SSLSessionBindingEvent$method$getSession$053c67d6c8c9d2b9(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLSessionBindingEvent$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_javax_net_ssl_SSLSessionBindingEvent$method_info$getSession$053c67d6c8c9d2b9;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLSessionBindingEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *);
	struct _jc_object	*(*getSession$053c67d6c8c9d2b9)(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *);
};

// Vtable
struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_net_ssl_SSLSessionBindingEvent$vmethods	javax_net_ssl_SSLSessionBindingEvent;
};

// Vtype
struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLSessionBindingEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$refs {
    _jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs	javax_net_ssl_SSLSessionBindingEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs	javax_net_ssl_SSLSessionBindingEvent;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLSessionBindingEvent$object {
	_jc_javax_net_ssl_SSLSessionBindingEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLSessionBindingEvent$vtype	*vtype;
	_jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLSessionBindingEvent$vtype _jc_javax_net_ssl_SSLSessionBindingEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLSessionBindingEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLSessionBindingEvent$class_object;

#endif	/* _JC_javax_net_ssl_SSLSessionBindingEvent_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLSessionBindingEvent.h <==
// public class javax.net.ssl.SSLSessionBindingEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 8266a1b5be5d34a2 javax_net_ssl_SSLSessionBindingEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_net_ssl_SSLSessionBindingEvent_H_
#define _JC_javax_net_ssl_SSLSessionBindingEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_net_ssl_SSLSession$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs	_jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs	_jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$refs	_jc_javax_net_ssl_SSLSessionBindingEvent$refs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs	_jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs;
typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$object	_jc_javax_net_ssl_SSLSessionBindingEvent$object;

typedef struct _jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct	_jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLSessionBindingEvent$vmethods	_jc_javax_net_ssl_SSLSessionBindingEvent$vmethods;
typedef const struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtable	_jc_javax_net_ssl_SSLSessionBindingEvent$vtable;
typedef const struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtype	_jc_javax_net_ssl_SSLSessionBindingEvent$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_net_ssl_SSLSessionBindingEvent$fields_struct _jc_javax_net_ssl_SSLSessionBindingEvent$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLSessionBindingEvent$method$_init$0e0aa0347f23a9f5(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_SSLSessionBindingEvent$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_net_ssl_SSLSessionBindingEvent$method$getSession$053c67d6c8c9d2b9(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLSessionBindingEvent$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_javax_net_ssl_SSLSessionBindingEvent$method_info$getSession$053c67d6c8c9d2b9;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLSessionBindingEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSession$053c67d6c8c9d2b9)(_jc_env *, struct _jc_javax_net_ssl_SSLSessionBindingEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_net_ssl_SSLSessionBindingEvent$vmethods	javax_net_ssl_SSLSessionBindingEvent;
};

// Vtype
struct _jc_javax_net_ssl_SSLSessionBindingEvent$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLSessionBindingEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$refs {
    _jc_javax_net_ssl_SSLSessionBindingEvent$sub_refs	javax_net_ssl_SSLSessionBindingEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_net_ssl_SSLSessionBindingEvent$sub_nonrefs	javax_net_ssl_SSLSessionBindingEvent;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLSessionBindingEvent$object {
	_jc_javax_net_ssl_SSLSessionBindingEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLSessionBindingEvent$vtype	*vtype;
	_jc_javax_net_ssl_SSLSessionBindingEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLSessionBindingEvent$vtype _jc_javax_net_ssl_SSLSessionBindingEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLSessionBindingEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLSessionBindingEvent$class_object;

#endif	/* _JC_javax_net_ssl_SSLSessionBindingEvent_H_ */
